Functional Architecture

Knowledge
Delivery

Consumer Interfaces

RAG API

Knowledge Portal

Chatbot SDK

Copilot Plugin

Access Control

AuthN/AuthZ

RBAC Engine

Knowledge
Retrieval

Query Processing

Query Parser

Intent Classifier

Search Engine

Vector Search

Keyword Search

Generation

Reranker

Context Builder

Knowledge
Storage

Vector Store

Embeddings

Document Store

Raw Content

Metadata Store

Catalog

Graph Store

Relationships

Knowledge
Ingestion

Connectors

Confluence

SharePoint

OneDrive

Email

Processing

ETL Pipeline

Chunker

Enrichment

Embedding Service

Tagger